/*
 *	The Remote User Info Distribution Protocol
 *
 *	(c) 1997--2010 Martin Mares <mj@ucw.cz>
 */

#include <inttypes.h>
#include <netinet/in.h>

typedef uint32_t u32;

#define MAX_USERS 128

struct userinfo {
  char name[10];
  char con[8];
  char mesg_y;
  char pad;
  u32 login_time;
  u32 idle_time;
};

struct nwho_pkt {
  u32 magic;				/* Guard against ancient nwho versions */
  u32 local_time;
  u32 server_time;			/* Reserved for use by the server */
  u32 num_users;
  u32 uptime;
  u32 avl[3];
  struct userinfo users[MAX_USERS];
};

#define NWHO_SPOOL_DIR "/var/state/nwho"
#define NWHO_MAGIC 0x21913332
#define NWHO_PORT 811

#define DEFAULT_SEND_TIME 30
#define DEFAULT_PRUNE_TIME 30
#define DEFAULT_DOWN_TIME 120
#define DEFAULT_DEAD_TIME 4*86400

#define STRINGIFY(x) STRINGIFY2(x)
#define STRINGIFY2(x) #x

static inline int nwho_pkt_size(struct nwho_pkt *pkt)
{
  return sizeof(struct nwho_pkt) - (MAX_USERS - ntohl(pkt->num_users))*sizeof(struct userinfo);
}

/* util.c */

void die(char *msg, ...) __attribute__((noreturn));
